@@ -26,6 +26,7 @@ setLocalTranslate('cl_core3',sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
 from calculate.lib.utils.files import process,readFile,processProgress
+from calculate.lib.cl_template import TemplatesError
 from calculate.lib.utils.content import getCfgFiles
 from itertools import *
 
@@ -148,7 +149,7 @@ class CommonMethods:
         try:
             dirsFiles = clTempl.applyTemplates()
             if clTempl.getError():
-                raise InstallError(clTempl.getError())
+                raise TemplatesError(clTempl.getError())
         finally:
             if clTempl:
                 if clTempl.cltObj:
