@@ -1,6 +1,6 @@
 #-*- coding: utf-8 -*-
 
-# Copyright 2010-2012 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2011-2013 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ from os import path
 
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.core.server.decorators import Dec
+import pwd
 #from calculate.api.cert_cmd import find_id_cert
 setLocalTranslate('cl_core3',sys.modules[__name__])
 
@@ -26,6 +27,7 @@ from calculate.lib.utils.files import listDirectory
 from calculate.lib.utils.portage import isPkgInstalled,reVerSplitToPV, \
                                         getPkgSlot
 from calculate.lib.utils.common import getTupleVersion
+from calculate.lib.variables.user import VariableUrLogin
 from itertools import *
 import glob
 
@@ -136,7 +138,10 @@ class VariableClCorePkgCategory(Variable):
     def get(self):
         category = isPkgInstalled(self.Get('cl_core_pkg_name'))
         if category:
-            category = category[0].rpartition('/')[2]
+            if type(category[0]) == dict:
+                category = ""
+            else:
+                category = category[0].rpartition('/')[2]
         else:
             choice = self.choice()
             if len(choice) == 1:
@@ -208,3 +213,20 @@ class VariableClCorePkgRootSet(Variable):
     def init(self):
         self.label = _("Configure dependent packages in root")
         self.help = _("configure the dependent packages in the same directory as the specified package, instead of root")
+
+class VariableUrCoreLogin(VariableUrLogin):
+    """
+    User Login
+    """
+    opt = ["--login"]
+    alias = "ur_login"
+
+    def check(self,value):
+        """Пользователь существует"""
+        try:
+            pwd.getpwnam(value).pw_gid
+        except:
+            raise VariableError(_("User %s does not exist")%value)
+
+    def get(self):
+        return self.Get('ur_login')
